Affiliated Packages
-------------------

As a community project, our goal is to provide a base package that gives users something useful out of the box, but enables them to improve upon what we've delivered as needed. As such, we're hope that the community will take their creations and feed them back into the TOM ecosystem. We've set up this page to keep track of any community-developed tools and interesting ideas--if you happen to have a project with any custom code that the community would find useful, please let us know and we can add it here!

*******
tom_iag
*******

The `tom_iag <https://github.com/thusser/tom_iag>`_ plugin provides and interface to the MONET IAG telescopes, and was developed by Tim-Oliver Husser.

********************
tom_gemini_community
********************

The `tom_gemini_community <https://github.com/TOMToolkit/tom_gemini_community>`_ plugin provides additional features for making observation requests to Gemini, and includes support for guide star selection via `tom_gemini_community <https://github.com/bryanmiller/gsselect>`_. The plugin was developed by Bryan Miller.

****************
SNEx Custom Code
****************

The `updated SNEx codebase <https://github.com/jfrostburke/snex2>`_ contains the following custom elements:

* `Custom forms for submission to LCO and Gemini <https://github.com/jfrostburke/snex2/tree/master/custom_code/facilities>`_
* `Custom catalog search of MARS <https://github.com/jfrostburke/snex2/blob/master/custom_code/harvesters/mars_harvester.py>`_
* `Moon visibility plot <https://github.com/jfrostburke/snex2/blob/master/custom_code/templatetags/custom_code_tags.py#L223>`_, among other custom plots
* `View of recent TNS target data <https://github.com/jfrostburke/snex2/blob/master/custom_code/views.py#L44>`_
